from flask import Flask, request, redirect, render_template
import json
import os

app = Flask(__name__)

URL_FILE = "urls.json"

# Load or create empty mapping
if os.path.exists(URL_FILE):
    with open(URL_FILE) as f:
        url_map = json.load(f)
else:
    url_map = {}

def save_urls():
    with open(URL_FILE, "w") as f:
        json.dump(url_map, f)

@app.route("/")
def index():
    return render_template("index.html")

@app.route("/generate", methods=["POST"])
def generate():
    target_url = request.form.get("target")
    if not target_url:
        return "Missing target URL", 400

    from random import choice
    import string

    def gen_sub(n=5):
        return ".".join(
            "".join(choice(string.ascii_lowercase) for _ in range(1))
            for _ in range(n)
        )

    subdomain = gen_sub()
    url_map[subdomain] = target_url
    save_urls()

    long_url = f"https://{subdomain}.yourproject.hackclub.app"
    return f"Your long link: <a href='{long_url}'>{long_url}</a>"

@app.route("/", defaults={"path": ""})
@app.route("/<path:path>")
def redirector(path):
    host = request.host
    base = "yourproject.hackclub.app"
    if not host.endswith(base):
        return "Invalid domain", 400

    sub_part = host.replace("." + base, "")
    if sub_part in url_map:
        target = url_map[sub_part]
        return redirect(f"{target}/{path}", code=302)

    return "Link not found", 404
